@@ -6,7 +6,7 @@ void Daemon::createIPCfile()
 {
     string const &ipcFile = d_options.ipcFile();
 
-    unique_ptr<char> buffer(new char[ipcFile.length() + 6 + 1]);
+    unique_ptr<char []> buffer(new char[ipcFile.length() + 6 + 1]);
     strcpy(buffer.get() + ipcFile.copy(buffer.get(), string::npos), "XXXXXX");
 
     int fd = mkstemp(buffer.get());
